@@ -1,7 +1,7 @@
 /*
 
 Copyright (C) 1994, 1995, 1996, 1997, 1999, 2000, 2002, 2003, 2004,
-              2005, 2007 John W. Eaton
+              2005, 2007, 2008 John W. Eaton
 
 This file is part of Octave.
 
@@ -49,7 +49,7 @@ SVD::left_singular_matrix (void) const
   if (type_computed == SVD::sigma_only)
     {
       (*current_liboctave_error_handler)
-	("ComplexSVD: U not computed because type == SVD::sigma_only");
+	("SVD: U not computed because type == SVD::sigma_only");
       return Matrix ();
     }
   else
@@ -62,7 +62,7 @@ SVD::right_singular_matrix (void) const
   if (type_computed == SVD::sigma_only)
     {
       (*current_liboctave_error_handler)
-	("ComplexSVD: V not computed because type == SVD::sigma_only");
+	("SVD: V not computed because type == SVD::sigma_only");
       return Matrix ();
     }
   else
@@ -144,28 +144,18 @@ SVD::init (const Matrix& a, SVD::type svd_type)
 			     F77_CHAR_ARG_LEN (1)
 			     F77_CHAR_ARG_LEN (1)));
 
-  if (f77_exception_encountered)
-    (*current_liboctave_error_handler) ("unrecoverable error in dgesvd");
-  else
-    {
-      lwork = static_cast<octave_idx_type> (work(0));
-      work.resize (lwork);
+  lwork = static_cast<octave_idx_type> (work(0));
+  work.resize (lwork);
 
-      F77_XFCN (dgesvd, DGESVD, (F77_CONST_CHAR_ARG2 (&jobu, 1),
-				 F77_CONST_CHAR_ARG2 (&jobv, 1),
-				 m, n, tmp_data, m, s_vec, u, m, vt,
-				 nrow_vt, work.fortran_vec (), lwork, info
-				 F77_CHAR_ARG_LEN (1)
-				 F77_CHAR_ARG_LEN (1)));
+  F77_XFCN (dgesvd, DGESVD, (F77_CONST_CHAR_ARG2 (&jobu, 1),
+			     F77_CONST_CHAR_ARG2 (&jobv, 1),
+			     m, n, tmp_data, m, s_vec, u, m, vt,
+			     nrow_vt, work.fortran_vec (), lwork, info
+			     F77_CHAR_ARG_LEN (1)
+			     F77_CHAR_ARG_LEN (1)));
 
-      if (f77_exception_encountered)
-	(*current_liboctave_error_handler) ("unrecoverable error in dgesvd");
-      else
-	{
-	  if (! (jobv == 'N' || jobv == 'O'))
-	    right_sm = right_sm.transpose ();
-	}
-    }
+  if (! (jobv == 'N' || jobv == 'O'))
+    right_sm = right_sm.transpose ();
 
   return info;
 }
