@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 1999, 2000, 2002, 2005, 2006, 2007 John W. Eaton
+Copyright (C) 1999, 2000, 2002, 2005, 2006, 2007, 2008 John W. Eaton
 
 This file is part of Octave.
 
@@ -25,7 +25,6 @@ along with Octave; see the file COPYING.  If not, see
 #endif
 
 #include <climits>
-#include <cmath>
 #include <ctime>
 
 #ifdef HAVE_UNISTD_H
@@ -42,6 +41,7 @@ along with Octave; see the file COPYING.  If not, see
 #endif
 
 #include "lo-error.h"
+#include "lo-math.h"
 #include "lo-utils.h"
 #include "oct-time.h"
 
@@ -291,6 +291,9 @@ octave_base_tm::strftime (const std::string& fmt) const
 void
 octave_base_tm::init (void *p)
 {
+  if (! p)
+    return;
+
   struct tm *t = static_cast<struct tm*> (p);
   
   tm_sec = t->tm_sec;
@@ -304,7 +307,8 @@ octave_base_tm::init (void *p)
   tm_isdst = t->tm_isdst;
 
 #if defined (HAVE_STRUCT_TM_TM_ZONE)
-  tm_zone = t->tm_zone;
+  if (t->tm_zone)
+    tm_zone = t->tm_zone;
 #elif defined (HAVE_TZNAME)
   if (t->tm_isdst == 0 || t->tm_isdst == 1)
     tm_zone = tzname[t->tm_isdst];
