@@ -1,5 +1,5 @@
 ## Copyright (C) 1995, 1996, 1997, 1999, 2000, 2002, 2004, 2005, 2006,
-##               2007 Kurt Hornik
+##               2007, 2009 Kurt Hornik
 ##
 ## This file is part of Octave.
 ##
@@ -19,18 +19,16 @@
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {} nextpow2 (@var{x})
-## If @var{x} is a scalar, returns the first integer @var{n} such that
-## @iftex
+## If @var{x} is a scalar, return the first integer @var{n} such that
 ## @tex
-##  $2^n \ge |x|$.
+## $2^n \ge |x|$.
 ## @end tex
-## @end iftex
-## @ifinfo
-##  2^n >= abs (x).
-## @end ifinfo
+## @ifnottex
+## 2^n >= abs (x).
+## @end ifnottex
 ##
 ## If @var{x} is a vector, return @code{nextpow2 (length (@var{x}))}.
-## @seealso{pow2}
+## @seealso{pow2, log2}
 ## @end deftypefn
 
 ## Author: KH <Kurt.Hornik@wu-wien.ac.at>
