@@ -1,11 +1,12 @@
-## Copyright (C) 1996, 1997 John W. Eaton
+## Copyright (C) 1994, 1995, 1996, 1997, 1999, 2000, 2005, 2006, 2007,
+##               2008, 2009 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
 ## Octave is free software; you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 2, or (at your option)
-## any later version.
+## the Free Software Foundation; either version 3 of the License, or (at
+## your option) any later version.
 ##
 ## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,9 +14,8 @@
 ## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, write to the Free
-## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-## 02110-1301, USA.
+## along with Octave; see the file COPYING.  If not, see
+## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {} poly (@var{a})
@@ -24,10 +24,12 @@
 ## the characteristic polynomial of @var{a}.  As an example we can use
 ## this to find the eigenvalues of @var{a} as the roots of @code{poly (@var{a})}.
 ## @example
+## @group
 ## roots(poly(eye(3)))
 ## @result{} 1.00000 + 0.00000i
 ## @result{} 1.00000 - 0.00000i
 ## @result{} 1.00000 + 0.00000i
+## @end group
 ## @end example
 ## In real-life examples you should, however, use the @code{eig} function
 ## for computing eigenvalues.
@@ -75,3 +77,12 @@ function y = poly (x)
   endif
 
 endfunction
+
+%!assert(all (all (poly ([1, 2, 3]) == [1, -6, 11, -6])));
+
+%!assert(all (all (abs (poly ([1, 2; 3, 4]) - [1, -5, -2]) < sqrt (eps))));
+
+%!error poly ([1, 2, 3; 4, 5, 6]);
+
+%!assert(poly ([]),1);
+
