@@ -1,7 +1,7 @@
 /*
 
 Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2002, 2003,
-              2004, 2005, 2006, 2007 John W. Eaton
+              2004, 2005, 2006, 2007, 2008, 2009 John W. Eaton
 
 This file is part of Octave.
 
@@ -96,7 +96,7 @@ octave_change_to_directory (const std::string& newdir)
   return cd_ok;
 }
 
-DEFCMD (cd, args, ,
+DEFUN (cd, args, ,
   "-*- texinfo -*-\n\
 @deffn {Command} cd dir\n\
 @deffnx {Command} chdir dir\n\
@@ -188,7 +188,7 @@ system-dependent error message.\n\
 	  if (dir)
 	    {
 	      string_vector dirlist = dir.read ();
-	      retval(0) = Cell (dirlist.qsort ());
+	      retval(0) = Cell (dirlist.sort ());
 	      retval(1) = 0.0;
 	    }
 	  else
@@ -206,11 +206,11 @@ system-dependent error message.\n\
 // FIXME -- should maybe also allow second arg to specify
 // mode?  OTOH, that might cause trouble with compatibility later...
 
-DEFCMD (mkdir, args, ,
+DEFUN (mkdir, args, ,
   "-*- texinfo -*-\n\
 @deftypefn {Built-in Function} {[@var{status}, @var{msg}, @var{msgid}] =} mkdir (@var{dir})\n\
 @deftypefnx {Built-in Function} {[@var{status}, @var{msg}, @var{msgid}] =} mkdir (@var{parent}, @var{dir})\n\
-Create a directory named @var{dir}.\n\
+Create a directory named @var{dir} in the directory @var{parent}.\n\
 \n\
 If successful, @var{status} is 1, with @var{msg} and @var{msgid} empty\n\
 character strings.  Otherwise, @var{status} is 0, @var{msg} contains a\n\
@@ -289,7 +289,7 @@ message identifier.\n\
   return retval;
 }
 
-DEFCMD (rmdir, args, ,
+DEFUN (rmdir, args, ,
   "-*- texinfo -*-\n\
 @deftypefn {Built-in Function} {[@var{status}, @var{msg}, @var{msgid}] =} rmdir (@var{dir})\n\
 @deftypefnx {Built-in Function} {[@var{status}, @var{msg}, @var{msgid}] =} rmdir (@var{dir}, @code{\"s\"})\n\
@@ -637,33 +637,81 @@ fnmatch (\"a*b\", @{\"ab\"; \"axyzb\"; \"xyzab\"@})\n\
 DEFUN (filesep, args, ,
   "-*- texinfo -*-\n\
 @deftypefn {Built-in Function} {} filesep ()\n\
+@deftypefnx {Built-in Function} {} filesep ('all')\n\
 Return the system-dependent character used to separate directory names.\n\
+\n\
+If 'all' is given, the function return all valid file separators in\n\
+the form of a string.  The list of file separators is system-dependent.\n\
+It is / (forward slash) under UNIX or Mac OS X, / and \\ (forward and\n\
+backward slashes) under Windows.\n\
 @seealso{pathsep, dir, ls}\n\
 @end deftypefn")
 {
   octave_value retval;
 
   if (args.length () == 0)
-    retval = file_ops::dir_sep_str;
+    retval = file_ops::dir_sep_str ();
+  else if (args.length () == 1)
+    {
+      std::string s = args(0).string_value ();
+
+      if (! error_state)
+	{
+	  if (s == "all")
+	    retval = file_ops::dir_sep_chars ();
+	  else
+	    gripe_wrong_type_arg ("filesep", args(0));
+	}
+      else
+	gripe_wrong_type_arg ("filesep", args(0));
+    }
   else
     print_usage ();
 
   return retval;
 }
 
-DEFUN (pathsep, args, ,
+DEFUN (pathsep, args, nargout,
     "-*- texinfo -*-\n\
-@deftypefn {Built-in Function} {} pathsep ()\n\
-Return the system-dependent character used to separate directories in\n\
+@deftypefn {Built-in Function} {@var{val} =} pathsep ()\n\
+@deftypefnx {Built-in Function} {@var{old_val} =} pathsep (@var{new_val})\n\
+Query or set the character used to separate directories in\n\
 a path.\n\
 @seealso{filesep, dir, ls}\n\
 @end deftypefn")
 {
   octave_value retval;
 
-  if (args.length () == 0)
-    retval = dir_path::path_sep_str;
-  else
+  int nargin = args.length ();
+
+  if (nargout > 0 || nargin == 0)
+    retval = dir_path::path_sep_str ();
+
+  if (nargin == 1)
+    {
+      std::string sval = args(0).string_value ();
+
+      if (! error_state)
+	{
+	  switch (sval.length ())
+	    {
+	    case 1:
+	      dir_path::path_sep_char (sval[0]);
+	      break;
+
+	    case 0:
+	      dir_path::path_sep_char ('\0');
+	      break;
+
+	    default:
+	      error ("pathsep: argument must be a single character");
+	      break;
+	    }
+	}
+      else
+	error ("pathsep: argument must be a single character");
+    }
+  else if (nargin > 1)
     print_usage ();
 
   return retval;
