@@ -1,13 +1,14 @@
 /*
 
-Copyright (C) 1996, 1997 John W. Eaton
+Copyright (C) 1994, 1995, 1996, 1997, 1999, 2002, 2003, 2004, 2005,
+              2006, 2007, 2008, 2009 John W. Eaton
 
 This file is part of Octave.
 
 Octave is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2, or (at your option) any
-later version.
+Free Software Foundation; either version 3 of the License, or (at your
+option) any later version.
 
 Octave is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -15,9 +16,8 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, write to the Free
-Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-02110-1301, USA.
+along with Octave; see the file COPYING.  If not, see
+<http://www.gnu.org/licenses/>.
 
 */
 
@@ -37,6 +37,7 @@ class tree_walker;
 
 #include "base-list.h"
 #include "pt-decl.h"
+#include "symtab.h"
 
 // Parameter lists.  Used to hold the list of input and output
 // parameters in a function definition.  Elements are identifiers
@@ -47,6 +48,12 @@ tree_parameter_list : public octave_base_list<tree_decl_elt *>
 {
 public:
 
+  enum in_or_out
+    {
+      in = 1,
+      out = 2
+    };
+
   tree_parameter_list (void)
     : marked_for_varargs (0) { }
 
@@ -57,12 +64,10 @@ public:
 
   void mark_as_formal_parameters (void);
 
-  void mark_varargs (void) { marked_for_varargs = 1; }
+  bool validate (in_or_out type);
 
   bool takes_varargs (void) const { return marked_for_varargs != 0; }
 
-  void mark_varargs_only (void) { marked_for_varargs = -1; }
-
   bool varargs_only (void) { return (marked_for_varargs < 0); }
 
   void initialize_undefined_elements (const std::string& warnfor,
@@ -76,7 +81,8 @@ public:
 
   octave_value_list convert_to_const_vector (const Cell& varargout);
 
-  tree_parameter_list *dup (symbol_table *sym_tab);
+  tree_parameter_list *dup (symbol_table::scope_id scope,
+			    symbol_table::context_id context) const;
 
   void accept (tree_walker& tw);
 
@@ -84,6 +90,10 @@ private:
 
   int marked_for_varargs;
 
+  void mark_varargs (void) { marked_for_varargs = 1; }
+
+  void mark_varargs_only (void) { marked_for_varargs = -1; }
+
   // No copying!
 
   tree_parameter_list (const tree_parameter_list&);
@@ -105,7 +115,8 @@ public:
 
   ~tree_return_list (void);
 
-  tree_return_list *dup (symbol_table *sym_tab);
+  tree_return_list *dup (symbol_table::scope_id scope,
+			 symbol_table::context_id context) const;
 
   void accept (tree_walker& tw);
 
