@@ -252,11 +252,16 @@ do\n\
   endif\n\
 until (done)\n\
 fclose (out);\n\
-     @print{} are\n\
-     @print{} some\n\
-     @print{} strings\n\
+waitpid (pid);\n\
      @print{} these\n\
+     @print{} strings\n\
+     @print{} some\n\
+     @print{} are\n\
 @end example\n\
+\n\
+Note that @code{popen2}, unlike @code{popen}, will not \"reap\" the\n\
+child process.  If you don't use @code{waitpid} to check the child's\n\
+exit status, it will linger until Octave exits.\n\
 @end deftypefn")
 {
   octave_value_list retval;
