@@ -1,6 +1,6 @@
 #!/bin/sh
 
-# Copyright (C) 2006, 2007 David Bateman
+# Copyright (C) 2006, 2007, 2008, 2009 David Bateman
 #
 # This file is part of Octave.
 # 
@@ -180,11 +180,11 @@ cat >>$TESTS <<EOF
 %% of a singular matrix, which is consistent with the full matrix
 %% behaviour. They are therefore disabled.. 
 %!testif HAVE_UMFPACK
-%! assert(spinv(sparse([1,1;1,1+i])),sparse([1-1i,1i;1i,-1i]),10*eps);
-% !error spinv( sparse( [1,1;1,1]   ) );
-% !error spinv( sparse( [0,0;0,1]   ) );
-% !error spinv( sparse( [0,0;0,1+i] ) );
-% !error spinv( sparse( [0,0;0,0]   ) );
+%! assert(inv(sparse([1,1;1,1+i])),sparse([1-1i,1i;1i,-1i]),10*eps);
+% !error inv( sparse( [1,1;1,1]   ) );
+% !error inv( sparse( [0,0;0,1]   ) );
+% !error inv( sparse( [0,0;0,1+i] ) );
+% !error inv( sparse( [0,0;0,0]   ) );
 
 %% error handling in constructor
 %!error sparse(1,[2,3],[1,2,3]);
@@ -216,7 +216,7 @@ gen_specific_tests() {
 %!test
 %! wdbz = warning ("query", "Octave:divide-by-zero");
 %! warning ("off", "Octave:divide-by-zero");
-%! assert(full(sparse(eye(3))/0),eye(3)/0);
+%! assert(full(sparse(eye(3))/0),full(eye(3)/0));
 %! warning (wdbz.state, "Octave:divide-by-zero");
 
 EOF
@@ -388,18 +388,18 @@ EOF
 gen_matrixdiag_tests() {
     cat >>$TESTS <<EOF
 %% Matrix diagonal tests (uses af,as,bf,bs)
-%!assert(spdiag(as),sparse(diag(af)))
-%!assert(spdiag(bs),sparse(diag(bf)))
-%!assert(spdiag(as,1),sparse(diag(af,1)))
-%!assert(spdiag(bs,1),sparse(diag(bf,1)))
-%!assert(spdiag(as,-1),sparse(diag(af,-1)))
-%!assert(spdiag(bs,-1),sparse(diag(bf,-1)))
-%!assert(spdiag(as(:)),sparse(diag(af(:))))
-%!assert(spdiag(as(:),1),sparse(diag(af(:),1)))
-%!assert(spdiag(as(:),-1),sparse(diag(af(:),-1)))
-%!assert(spdiag(as(:)'),sparse(diag(af(:)')))
-%!assert(spdiag(as(:)',1),sparse(diag(af(:)',1)))
-%!assert(spdiag(as(:)',-1),sparse(diag(af(:)',-1)))
+%!assert(diag(as),sparse(diag(af)))
+%!assert(diag(bs),sparse(diag(bf)))
+%!assert(diag(as,1),sparse(diag(af,1)))
+%!assert(diag(bs,1),sparse(diag(bf,1)))
+%!assert(diag(as,-1),sparse(diag(af,-1)))
+%!assert(diag(bs,-1),sparse(diag(bf,-1)))
+%!assert(diag(as(:)),sparse(diag(af(:))))
+%!assert(diag(as(:),1),sparse(diag(af(:),1)))
+%!assert(diag(as(:),-1),sparse(diag(af(:),-1)))
+%!assert(diag(as(:)'),sparse(diag(af(:)')))
+%!assert(diag(as(:)',1),sparse(diag(af(:)',1)))
+%!assert(diag(as(:)',-1),sparse(diag(af(:)',-1)))
 %!assert(spdiags(as,[0,1]),[diag(af,0),diag(af,1)])
 %!test [tb,tc]=spdiags(as); 
 %! assert(spdiags(tb,tc,sparse(zeros(size(as)))),as)
@@ -531,42 +531,42 @@ gen_unaryop_tests() {
 %!assert(!issparse(af))
 %!assert(!(issparse(af)&&iscomplex(af)))
 %!assert(!(issparse(af)&&isreal(af)))
-%!assert(spsum(as),sparse(sum(af)))
-%!assert(spsum(as,1),sparse(sum(af,1)))
-%!assert(spsum(as,2),sparse(sum(af,2)))
-%!assert(spcumsum(as),sparse(cumsum(af)))
-%!assert(spcumsum(as,1),sparse(cumsum(af,1)))
-%!assert(spcumsum(as,2),sparse(cumsum(af,2)))
-%!assert(spsumsq(as),sparse(sumsq(af)))
-%!assert(spsumsq(as,1),sparse(sumsq(af,1)))
-%!assert(spsumsq(as,2),sparse(sumsq(af,2)))
-%!assert(spprod(as),sparse(prod(af)))
-%!assert(spprod(as,1),sparse(prod(af,1)))
-%!assert(spprod(as,2),sparse(prod(af,2)))
-%!assert(spcumprod(as),sparse(cumprod(af)))
-%!assert(spcumprod(as,1),sparse(cumprod(af,1)))
-%!assert(spcumprod(as,2),sparse(cumprod(af,2)))
+%!assert(sum(as),sparse(sum(af)))
+%!assert(sum(as,1),sparse(sum(af,1)))
+%!assert(sum(as,2),sparse(sum(af,2)))
+%!assert(cumsum(as),sparse(cumsum(af)))
+%!assert(cumsum(as,1),sparse(cumsum(af,1)))
+%!assert(cumsum(as,2),sparse(cumsum(af,2)))
+%!assert(sumsq(as),sparse(sumsq(af)))
+%!assert(sumsq(as,1),sparse(sumsq(af,1)))
+%!assert(sumsq(as,2),sparse(sumsq(af,2)))
+%!assert(prod(as),sparse(prod(af)))
+%!assert(prod(as,1),sparse(prod(af,1)))
+%!assert(prod(as,2),sparse(prod(af,2)))
+%!assert(cumprod(as),sparse(cumprod(af)))
+%!assert(cumprod(as,1),sparse(cumprod(af,1)))
+%!assert(cumprod(as,2),sparse(cumprod(af,2)))
 
-%!assert(spmin(as),sparse(min(af)))
-%!assert(full(spmin(as(:))),min(af(:)))
-%!assert(spmin(as,[],1),sparse(min(af,[],1)))
-%!assert(spmin(as,[],2),sparse(min(af,[],2)))
-%!assert(spmin(as,[],1),sparse(min(af,[],1)))
-%!assert(spmin(as,0),sparse(min(af,0)))
-%!assert(spmin(as,bs),sparse(min(af,bf)))
-%!assert(spmax(as),sparse(max(af)))
-%!assert(full(spmax(as(:))),max(af(:)))
-%!assert(spmax(as,[],1),sparse(max(af,[],1)))
-%!assert(spmax(as,[],2),sparse(max(af,[],2)))
-%!assert(spmax(as,[],1),sparse(max(af,[],1)))
-%!assert(spmax(as,0),sparse(max(af,0)))
-%!assert(spmax(as,bs),sparse(max(af,bf)))
+%!assert(min(as),sparse(min(af)))
+%!assert(full(min(as(:))),min(af(:)))
+%!assert(min(as,[],1),sparse(min(af,[],1)))
+%!assert(min(as,[],2),sparse(min(af,[],2)))
+%!assert(min(as,[],1),sparse(min(af,[],1)))
+%!assert(min(as,0),sparse(min(af,0)))
+%!assert(min(as,bs),sparse(min(af,bf)))
+%!assert(max(as),sparse(max(af)))
+%!assert(full(max(as(:))),max(af(:)))
+%!assert(max(as,[],1),sparse(max(af,[],1)))
+%!assert(max(as,[],2),sparse(max(af,[],2)))
+%!assert(max(as,[],1),sparse(max(af,[],1)))
+%!assert(max(as,0),sparse(max(af,0)))
+%!assert(max(as,bs),sparse(max(af,bf)))
 
 %!assert(as==as)
 %!assert(as==af)
 %!assert(af==as)
 %!test
-%! [ii,jj,vv,nr,nc] = spfind(as);
+%! [ii,jj,vv,nr,nc] = find(as);
 %! assert(af,full(sparse(ii,jj,vv,nr,nc)));
 %!assert(nnz(as),sum(af(:)!=0))
 %!assert(nnz(as),nnz(af))
@@ -581,21 +581,21 @@ gen_unaryop_tests() {
 %!error [i,j]=size(af);as(i-1,j+1);
 %!error [i,j]=size(af);as(i+1,j-1);
 %!test
-%! [Is,Js,Vs] = spfind(as);
+%! [Is,Js,Vs] = find(as);
 %! [If,Jf,Vf] = find(af);
 %! assert(Is,If);
 %! assert(Js,Jf);
 %! assert(Vs,Vf);
 %!error as(0,1);
 %!error as(1,0);
-%!assert(spfind(as),find(af))
+%!assert(find(as),find(af))
 %!test
-%! [i,j,v] = spfind(as);
+%! [i,j,v] = find(as);
 %! [m,n] = size(as);
 %! x = sparse(i,j,v,m,n);
 %! assert(x,as);
 %!test
-%! [i,j,v,m,n] = spfind(as);
+%! [i,j,v,m,n] = find(as);
 %! x = sparse(i,j,v,m,n);
 %! assert(x,as);
 %!assert(issparse(horzcat(as,as)));
@@ -631,59 +631,59 @@ gen_square_tests() {
 
     cat >>$TESTS <<EOF
 %!testif HAVE_UMFPACK
-%! assert(spdet(bs+speye(size(bs))),det(bf+eye(size(bf))),100*eps*abs(det(bf+eye(size(bf)))))
+%! assert(det(bs+speye(size(bs))),det(bf+eye(size(bf))),100*eps*abs(det(bf+eye(size(bf)))))
 
 %!testif HAVE_UMFPACK 
-%! [l,u]=splu(sparse([1,1;1,1]));
+%! [l,u]=lu(sparse([1,1;1,1]));
 %! assert(l*u,[1,1;1,1],10*eps);
 
 %!testif HAVE_UMFPACK
-%! [l,u]=splu(sparse([1,1;1,1+i]));
+%! [l,u]=lu(sparse([1,1;1,1+i]));
 %! assert(l,sparse([1,2,2],[1,1,2],1),10*eps);
 %! assert(u,sparse([1,1,2],[1,2,2],[1,1,1i]),10*eps);
 
 %!testif HAVE_UMFPACK ;# permuted LU
-%! [L,U] = splu(bs);
+%! [L,U] = lu(bs);
 %! assert(L*U,bs,1e-10);
 
 %!testif HAVE_UMFPACK ;# simple LU + row permutations
-%! [L,U,P] = splu(bs);
+%! [L,U,P] = lu(bs);
 %! assert(P'*L*U,bs,1e-10);
 %! # triangularity
-%! [i,j,v]=spfind(L);
+%! [i,j,v]=find(L);
 %! assert(i-j>=0);
-%! [i,j,v]=spfind(U);
+%! [i,j,v]=find(U);
 %! assert(j-i>=0);
 
 %!testif HAVE_UMFPACK ;# simple LU + row/col permutations
-%! [L,U,P,Q] = splu(bs);
+%! [L,U,P,Q] = lu(bs);
 %! assert(P'*L*U*Q',bs,1e-10);
 %! # triangularity
-%! [i,j,v]=spfind(L);
+%! [i,j,v]=find(L);
 %! assert(i-j>=0);
-%! [i,j,v]=spfind(U);
+%! [i,j,v]=find(U);
 %! assert(j-i>=0);
 
-%!testif HAVE_UMFPACK ;# LU with fixed column permutation
-%! [L,U,P] = splu(bs,colamd(bs));
-%! assert(P'*L*U,bs,1e-10);
+%!testif HAVE_UMFPACK ;# LU with vector permutations
+%! [L,U,P,Q] = lu(bs,'vector');
+%! assert(L(P,:)*U(:,Q),bs,1e-10);
 %! # triangularity
-%! [i,j,v]=spfind(L);
+%! [i,j,v]=find(L);
 %! assert(i-j>=0);
-%! [i,j,v]=spfind(U(:,colamd(bs)));
+%! [i,j,v]=find(U);
 %! assert(j-i>=0);
 
-%!testif HAVE_UMFPACK ;# LU with initial column permutation
-%! [L,U,P,Q] = splu(bs,colamd(bs));
-%! assert(P'*L*U*Q',bs,1e-10);
+%!testif HAVE_UMFPACK ;# LU with scaling
+%! [L,U,P,Q,R] = lu(bs);
+%! assert(R*P'*L*U*Q',bs,1e-10);
 %! # triangularity
-%! [i,j,v]=spfind(L);
+%! [i,j,v]=find(L);
 %! assert(i-j>=0);
-%! [i,j,v]=spfind(U);
+%! [i,j,v]=find(U);
 %! assert(j-i>=0);
 
 %!testif HAVE_UMFPACK ;# inverse
-%! assert(spinv(bs)*bs,sparse(eye(rows(bs))),1e-10);
+%! assert(inv(bs)*bs,sparse(eye(rows(bs))),1e-10);
 
 %!assert(bf\as',bf\af',100*eps);
 %!assert(bs\af',bf\af',100*eps);
@@ -696,25 +696,25 @@ EOF
 gen_cholesky_tests() {
     cat >>$TESTS <<EOF
 %!testif HAVE_CHOLMOD
-%! assert(spchol(bs)'*spchol(bs),bs,1e-10);
+%! assert(chol(bs)'*chol(bs),bs,1e-10);
 %!testif HAVE_CHOLMOD 
-%! assert(splchol(bs)*splchol(bs)',bs,1e-10);
+%! assert(chol(bs,'lower')*chol(bs,'lower')',bs,1e-10);
 %!testif HAVE_CHOLMOD
-%! assert(splchol(bs),spchol(bs)',1e-10);
+%! assert(chol(bs,'lower'),chol(bs)',1e-10);
 
 %!testif HAVE_CHOLMOD ;# Return Partial Cholesky factorization
-%! [RS,PS] = spchol(bs);
+%! [RS,PS] = chol(bs);
 %! assert(RS'*RS,bs,1e-10);
 %! assert(PS,0);
-%! [LS,PS] = splchol(bs);
+%! [LS,PS] = chol(bs,'lower');
 %! assert(LS*LS',bs,1e-10);
 %! assert(PS,0);
 
 %!testif HAVE_CHOLMOD ;# Permuted Cholesky factorization
-%! [RS,PS,QS] = spchol(bs);
+%! [RS,PS,QS] = chol(bs);
 %! assert(RS'*RS,QS*bs*QS',1e-10);
 %! assert(PS,0);
-%! [LS,PS,QS] = splchol(bs);
+%! [LS,PS,QS] = chol(bs,'lower');
 %! assert(LS*LS',QS*bs*QS',1e-10);
 %! assert(PS,0);
 
@@ -745,6 +745,48 @@ gen_rectangular_tests() {
     # gen_divop_tests # Disable rectangular \ and / for now
     gen_matrixdiag_tests
     gen_matrixreshape_tests
+    cat >>$TESTS <<EOF
+%!testif HAVE_UMFPACK ;# permuted LU
+%! [L,U] = lu(bs);
+%! assert(L*U,bs,1e-10);
+
+%!testif HAVE_UMFPACK ;# simple LU + row permutations
+%! [L,U,P] = lu(bs);
+%! assert(P'*L*U,bs,1e-10);
+%! # triangularity
+%! [i,j,v]=find(L);
+%! assert(i-j>=0);
+%! [i,j,v]=find(U);
+%! assert(j-i>=0);
+
+%!testif HAVE_UMFPACK ;# simple LU + row/col permutations
+%! [L,U,P,Q] = lu(bs);
+%! assert(P'*L*U*Q',bs,1e-10);
+%! # triangularity
+%! [i,j,v]=find(L);
+%! assert(i-j>=0);
+%! [i,j,v]=find(U);
+%! assert(j-i>=0);
+
+%!testif HAVE_UMFPACK ;# LU with vector permutations
+%! [L,U,P,Q] = lu(bs,'vector');
+%! assert(L(P,:)*U(:,Q),bs,1e-10);
+%! # triangularity
+%! [i,j,v]=find(L);
+%! assert(i-j>=0);
+%! [i,j,v]=find(U);
+%! assert(j-i>=0);
+
+%!testif HAVE_UMFPACK ;# LU with scaling
+%! [L,U,P,Q,R] = lu(bs);
+%! assert(R*P'*L*U*Q',bs,1e-10);
+%! # triangularity
+%! [i,j,v]=find(L);
+%! assert(i-j>=0);
+%! [i,j,v]=find(U);
+%! assert(j-i>=0);
+
+EOF
 }
 
 
@@ -879,13 +921,16 @@ gen_save_tests() {
 %! load(savefile,"as_save");
 %! unlink(savefile);
 %! assert(as_save,sparse(af));
-%!test # save hdf5
+%!testif HAVE_HDF5 # save hdf5
 %! savefile= tmpnam();
 %! as_save=as; save("-hdf5",savefile,"bf","as_save","af");
 %! clear as_save;
 %! load(savefile,"as_save");
 %! unlink(savefile);
 %! assert(as_save,sparse(af));
+## FIXME -- we should skip (or mark as an expected failure) the test for
+## saving sparse matrices to MAT files when using 64-bit indexing since
+## that is not implemented yet.
 %!test # save matlab
 %! savefile= tmpnam();
 %! as_save=as; save("-mat",savefile,"bf","as_save","af");
@@ -1020,20 +1065,20 @@ cat >>$TESTS <<EOF
 %!test
 %! us = alpha*[speye(11,9),[1;sparse(8,1);1;0]];
 %!testif HAVE_CXSPARSE
-%! [c,r] = spqr (us, xf);
+%! [c,r] = qr (us, xf);
 %! assert(us\xf,r\c,100*eps)
 %!testif HAVE_CXSPARSE
-%! [c,r] = spqr (us, xs);
+%! [c,r] = qr (us, xs);
 %! r = matrix_type(r,"Singular"); ## Force Matrix Type
 %! assert(us\xs,r\c,100*eps)
 %!test
 %! pus = us(:,[1:8,10,9]);
 %!testif HAVE_CXSPARSE
-%! [c,r] = spqr (pus, xf);
+%! [c,r] = qr (pus, xf);
 %! r = matrix_type(r,"Singular"); ## Force Matrix Type
 %! assert(pus\xf,r\c,100*eps)
 %!testif HAVE_CXSPARSE
-%! [c,r] = spqr (pus, xs);
+%! [c,r] = qr (pus, xs);
 %! r = matrix_type(r,"Singular"); ## Force Matrix Type
 %! assert(pus\xs,r\c,100*eps)
 %!test
@@ -1051,20 +1096,20 @@ cat >>$TESTS <<EOF
 %! xf = beta * ones(12,2);
 %! xs = speye(12,12);
 %!testif HAVE_CXSPARSE
-%! [c,r] = spqr (ls, xf);
+%! [c,r] = qr (ls, xf);
 %! assert(ls\xf,r\c,100*eps)
 %!testif HAVE_CXSPARSE
-%! [c,r] = spqr (ls, xs);
+%! [c,r] = qr (ls, xs);
 %! r = matrix_type(r,"Singular"); ## Force Matrix Type
 %! assert(ls\xs,r\c,100*eps)
 %!testif HAVE_CXSPARSE
 %! pls = ls(:,[1:8,10,9]);
 %!testif HAVE_CXSPARSE
-%! [c,r] = spqr (pls, xf);
+%! [c,r] = qr (pls, xf);
 %! r = matrix_type(r,"Singular"); ## Force Matrix Type
 %! assert(pls\xf,r\c,100*eps)
 %!testif HAVE_CXSPARSE
-%! [c,r] = spqr (pls, xs);
+%! [c,r] = qr (pls, xs);
 %! r = matrix_type(r,"Singular"); ## Force Matrix Type
 %! assert(pls\xs,r\c,100*eps)
 
